#
# spec file for package clipgrab
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2008-2013 detlef@links2linux.de
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           clipgrab
Version:        3.9.10
Release:        1.5
Summary:        Video downloader
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Video/Editors and Convertors
URL:            https://clipgrab.org
Source0:        https://download.clipgrab.org/%{name}-%{version}.tar.gz
Source1:        %{name}.desktop
BuildRequires:  ImageMagick-extra
BuildRequires:  hicolor-icon-theme >= 0.15
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Network) >= 5.9
BuildRequires:  pkgconfig(Qt5WebEngine) >= 5.9
BuildRequires:  pkgconfig(Qt5Xml) >= 5.9
Requires:       ffmpeg

%description
A program which downloads and converts online videos from YouTube, Vimeo,
DailyMotion, MyVideo and many other platforms.

%prep
%setup -q
chmod 0644 COPYING

%build
# none too clean, but it beats depending on icns-utils which has problems on non-x86 archs
dd if=%{name}.icns of=icon512.jp2 bs=1 skip=71836 count=79384
for s in 16 32 128 256 512; do
    convert -strip -resize ${s}x${s} icon512.jp2 ${s}.png
done

%qmake5 %{name}.pro
%make_build

%install
install -D -m0644 %{SOURCE1} %{buildroot}/%{_datadir}/applications/%{name}.desktop
install -D -m0755 %{name} %{buildroot}/%{_bindir}/%{name}
for s in 16 32 128 256 512; do
    install -D -m0644 "${s}.png" "%{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/%{name}.png"
done
%suse_update_desktop_file -r %{name} Video Editor

%files
%license COPYING
%{_bindir}/clipgrab
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png

%changelog
* Thu Feb  8 2024 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.9.10 (no changelog supplied)
* Mon Oct 18 2021 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.9.7 (no changelog supplied)
- Run spec-cleaner
- Drop post/postun for desktop_database
* Tue Nov 17 2020 ecsos <ecsos@opensuse.org>
- Update to version 3.9.2 (no changelog supplied)
* Wed May  8 2019 ecsos@opensuse.org
- Update to version 3.8.2 (no changelog supplied)
* Wed Jan 23 2019 aloisio@gmx.com
- Update to version 3.8.0 (no changelog supplied)
- Dropped clipgrab-qt5.patch (now builds natively against Qt5)
* Tue Dec 25 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.7.2 (no changelog supplied)
- Fix build with Qt 5.12
- Refreshed clipgrab-qt5.patch
* Sat Oct 27 2018 Luigi Baldoni <aloisio@gmx.com>
- Update to version 3.7.1 (no changelog supplied)
- Refreshed clipgrab-qt5.patch
- Spec cleanup
* Sun Apr 15 2018 ecsos@opensuse.org
- Update to version 3.6.8 (no changelog supplied)
- Rebase clipgrab-qt5.patch
* Thu Aug 17 2017 aloisio@gmx.com
- Update to version 3.6.5
* Sat Jun 24 2017 bwiedemann@suse.com
- use convert -strip to not add timestamps to .png files
* Sat Apr 29 2017 aloisio@gmx.com
- Removed dependency on icns-utils
* Fri Apr 28 2017 aloisio@gmx.com
- Update to version 3.6.4
- Dropped clipgrab-icons.zip as source and generate icons
  internally.
- Added clipgrab-qt5.patch and build against Qt5 libs.
- Spec cleanup
* Sun May 22 2016 seife+obs@b1-systems.com
- update to version 3.5.6
  no changelog file :-(
* Sun Jun  7 2015 seife+obs@b1-systems.com
- update to version 3.4.11:
  no changes file, stuff found in diff:
  - more translations
  - youtube fix
  - different SSL handling?
* Tue Dec 23 2014 seife+obs@b1-systems.com
- new upstream version 3.4.8:
  no changes file, stuff found in diff:
  - more translations
  - translation fixes
  - youtube fix
* Fri Oct 10 2014 seife+obs@b1-systems.com
- new upstream version 3.4.7:
  no changes file, stuff found in diff:
  - more translations
  - vimeo fixes
  - youtube regexp fix
* Sat Mar 22 2014 seife+obs@b1-systems.com
- new upstream version 3.4.2:
  no changes file, stuff found in diff:
  - youtube login support
  - chinese translation
* Wed Dec 18 2013 seife+obs@b1-systems.com
- new upstream version 3.3.0.4:
- no changes file, stuff found in diff:
  - changes to youtube code
  - some code reorganization
* Sun Aug  4 2013 seife+obs@b1-systems.com
- new upstream version 3.2.1.2:
- no changes file, obvious stuff extracted from diff:
  - remove sevenload and collegehumor, add metacafe
  - fixes for dailymotion, myvideo
  - more formats for youtube
  - various other fixes
* Sat Apr 13 2013 malcolmlewis@opensuse.org
- Updated to version 3.2.0.11:
  + No changelog file.
- Spec file clean up.
* Thu Feb 14 2013 seife+obs@b1-systems.com
- new upstream version 3.2.0.10
  - looks like a youtube fix / improvement (no changelog inside...)
* Mon Sep 17 2012 seife+obs@b1-systems.com
- new upstream version 3.2.0.9
  - looks like a youtube fix (no changelog inside...)
* Thu Aug 16 2012 seife+obs@b1-systems.com
- new upstream version <3.2.0.8>
* Mon Apr 30 2012 seife+obs@b1-systems.com
- new upstream version <3.2.0.5>
* Sun Nov 20 2011 reddwarf@opensuse.org
- new upstrean version <3.1.3.0>
- fix >12.1 build
* Sat Aug  6 2011 detlef@links2linux.de
- new upstream version <3.1.0.2>
* Sat Jul 23 2011 detlef@links2linux.de
- fix typo in clipgrap.desktop
* Wed Jul 14 2010 detlef@links2linux.de
- new upstream version <3.0.7.1>
* Sat Jul 10 2010 detlef@links2linux.de
- new upstream version <3.0.7>
* Mon Apr 19 2010 detlef@links2linux.de
- new upstream version <3.0.6.6>
* Thu Apr  8 2010 detlef@links2linux.de
- new upstream version <3.0.6.5>
* Fri Apr  2 2010 detlef@links2linux.de
- new upstream version <3.0.5.3>
* Mon Dec 28 2009 detlef@links2linux.de
- new upstream version <3.0.5>
* Mon Dec 21 2009 detlef@links2linux.de
- new upstream version <3.0.4.1>
* Mon Nov 30 2009 detlef@links2linux.de
- new upstream version <3.0.4>
* Thu Oct 29 2009 detlef@links2linux.de
- initial build clipgrab3
* Fri Mar 28 2008 detlef@links2linux.de
- initial build <2.0-beta2>
